def timestamp(self):
    """Get server timestamp (PUBLIC)
    
    Get server timestamp in milliseconds
    
    GET /timestamp
    
    Returns:
        int: Server timestamp in milliseconds
    """
    url_path = "/timestamp"
    response = self.query(url_path)
    return response.get("serverTimeMilli")



from typing import Union
from qe.lib.trading_enums import TradingPairMarketType


def trading_pairs(self, **kwargs):
    """Get trading pairs list (PUBLIC)
    
    Get list of trading pairs
    
    GET /pub/trading-pairs
    
    Keyword Args:
        page (int, optional): Page number for pagination
        pageSize (int, optional): Number of items per page
        exchange (str, optional): Exchange name filter
        marketType (TradingPairMarketType | str, optional): Market type filter
        isCoin (bool, optional): Coin filter
    """
    # 处理枚举类型参数
    if 'marketType' in kwargs and isinstance(kwargs['marketType'], TradingPairMarketType):
        kwargs['marketType'] = kwargs['marketType'].value
    
    url_path = "/pub/trading-pairs"
    return self.query(url_path, {**kwargs})



from qe.api import API


class Status(API):
    def __init__(self, api_key=None, api_secret=None, **kwargs):
        if "base_url" not in kwargs:
            kwargs["base_url"] = "https://api.quantumexecute.com"
        super().__init__(api_key, api_secret, **kwargs)

    # PUBLIC
    from qe.status.ping import ping
    from qe.status.timestamp import timestamp


"""
QE Connector Python SDK
"""
from .api import API
from .error import (
    Error,
    ClientError,
    APIError,
    ServerError,
    ParameterRequiredError,
    ParameterValueError,
    ParameterTypeError,
    ParameterArgumentError,
    WebsocketClientError
)

# WebSocket相关导入
from .ws import (
    WebSocketService,
    WebSocketEventHandlers,
    ClientPushMessage,
    MasterOrderMessage,
    OrderMessage,
    FillMessage,
    BaseThirdPartyMessage,
    ClientMessageType,
    ThirdPartyMessageType
)

__version__ = "1.0.4"

__all__ = [
    'API',
    'Error',
    'ClientError',
    'APIError',
    'ServerError',
    'ParameterRequiredError',
    'ParameterValueError',
    'ParameterTypeError',
    'ParameterArgumentError',
    'WebsocketClientError',
    'WebSocketService',
    'WebSocketEventHandlers',
    'ClientPushMessage',
    'MasterOrderMessage',
    'OrderMessage',
    'FillMessage',
    'BaseThirdPartyMessage',
    'ClientMessageType',
    'ThirdPartyMessageType'
]



from qe.api import API


class User(API):
    def __init__(self, api_key=None, api_secret=None, **kwargs):
        if "base_url" not in kwargs:
            kwargs["base_url"] = "https://api.quantumexecute.com"
        super().__init__(api_key, api_secret, **kwargs)

    # CONVERT
    from qe.user.exchange import list_exchange_apis
    from qe.user.trading import get_master_orders
    from qe.user.trading import get_master_order_detail
    from qe.user.trading import get_master_order_detail_by_client_order_id
    from qe.user.trading import get_order_fills
    from qe.user.trading import get_tca_analysis
    from qe.user.trading import create_master_order
    from qe.user.trading import cancel_master_order
    from qe.user.trading import create_listen_key



"""
WebSocket模块
"""
from .client import WebSocketService
from .types import (
    WebSocketEventHandlers,
    ClientPushMessage,
    MasterOrderMessage,
    OrderMessage,
    FillMessage,
    BaseThirdPartyMessage,
    ClientMessageType,
    ThirdPartyMessageType,
    WebSocketHandler,
    MasterOrderHandler,
    OrderHandler,
    FillHandler,
    StatusHandler,
    ErrorHandler,
    ConnectedHandler,
    DisconnectedHandler,
    RawMessageHandler
)

__all__ = [
    'WebSocketService',
    'WebSocketEventHandlers',
    'ClientPushMessage',
    'MasterOrderMessage',
    'OrderMessage',
    'FillMessage',
    'BaseThirdPartyMessage',
    'ClientMessageType',
    'ThirdPartyMessageType',
    'WebSocketHandler',
    'MasterOrderHandler',
    'OrderHandler',
    'FillHandler',
    'StatusHandler',
    'ErrorHandler',
    'ConnectedHandler',
    'DisconnectedHandler',
    'RawMessageHandler'
]
